rst = {
    "RstAnalyzer": {
        "method": "rst_analyzer"
    },
    "RstLoader": {
        "method": "rst_loader"
    },
    "TaskRepository": {
        "method": "rst_task_repository"
    },
    "LinkRepository": {
        "method": "rst_link_repository"
    },
    "ClassificationRepository": {
        "method": "rst_classification_repository"
    }
}
