base = {
    "QueryParser": {
        "method": "query_parser"
    },
    "TaskRepository": {
        "method": "memory_task_repository"
    },
    "LinkRepository": {
        "method": "memory_link_repository"
    },
    "ClassifierRepository": {
        "method": "memory_classifier_repository"
    },
    "ClassificationRepository": {
        "method": "memory_classification_repository"
    },
    "SlotRepository": {
        "method": "memory_slot_repository"
    },
    "PlotService": {
        "method": "memory_plot_service"
    },
    "ScheduleRepository": {
        "method": "memory_schedule_repository"
    },
    "EstimationManager": {
        "method": "estimation_manager"
    },
    "EstimarkInformer": {
        "method": "standard_estimark_informer"
    }
}
