json = {
    "ClassificationRepository": {
        "method": "json_classification_repository"
    },
    "ClassifierRepository": {
        "method": "json_classifier_repository"
    },
    "LinkRepository": {
        "method": "json_link_repository"
    },
    "ScheduleRepository": {
        "method": "json_schedule_repository"
    },
    "SlotRepository": {
        "method": "json_slot_repository"
    },
    "TaskRepository": {
        "method": "json_task_repository"
    }
}
